@@ -21,8 +21,9 @@ use ClearPress::Localize;
 use MIME::Base64 qw(encode_base64);
 use HTTP::Status qw(:constants);
 use JSON;
+use Readonly;
 
-our $VERSION = q[475.2.1];
+our $VERSION = q[475.3.3];
 our $DEBUG_OUTPUT   = 0;
 our $DEBUG_L10N     = 0;
 our $TEMPLATE_CACHE = {};
@@ -669,12 +670,13 @@ sub decor {
 }
 
 sub output_flush {
-  my $self = shift;
+  my ($self) = @_;
   $DEBUG_OUTPUT and carp "output_flush: @{[scalar @{$self->{output_buffer}}]} blobs in queue";
 
   eval {
-    print @{$self->{output_buffer}} or croak $ERRNO;
+    print grep { $_ } @{$self->{output_buffer}} or croak $ERRNO;
     1;
+
   } or do {
     #########
     # client stopped receiving (e.g. disconnect from lengthy streamed response)
@@ -689,6 +691,9 @@ sub output_flush {
 sub output_prepend {
   my ($self, @args) = @_;
   if(!$self->output_finished) {
+    if(scalar @args == 2 && $args[1] eq "\n" && !$args[0]) {
+      return;
+    }
     unshift @{$self->{output_buffer}}, grep { $_ } @args; # don't push undef or ""
     $DEBUG_OUTPUT and carp "output_prepend prepended (@{[scalar @args]} blobs)";
   }
@@ -698,6 +703,10 @@ sub output_prepend {
 sub output_buffer {
   my ($self, @args) = @_;
   if(!$self->output_finished) {
+    if(scalar @args == 2 && $args[1] eq "\n" && !$args[0]) {
+      return;
+    }
+
     push @{$self->{output_buffer}}, grep { $_ } @args; # don't push undef or ""
     $DEBUG_OUTPUT and carp "output_buffer added (@{[scalar @args]} blobs)";
   }
@@ -742,12 +751,32 @@ sub redirect {
   $self->headers->header('Location', $url);
 
   #########
-  # chances are we *always* want to do this
+  # - reset all previously output but unflushed content
+  # - push headers down the pipe, and html redirects
+  # - finish up
   #
   $self->output_reset();
-  $self->output_buffer($self->headers->as_string, "\n");
 
-  return 1;
+  Readonly::Scalar my $OVERFLOW => 1024;
+  if(length $self->headers->as_string > $OVERFLOW) { # fudge for apparent buffer overflow with apache+mod_perl (ParseHeaders related?)
+    carp q[warning: header block looks long];
+    $self->headers->remove_header('Location');
+    $self->headers->header('Status', HTTP_OK);
+  }
+
+  $self->output_buffer($self->headers->as_string, "\n");
+  $self->decorator->meta_refresh(qq[0;URL='$url']);
+
+  #########
+  # clean everything up and terminate
+  #
+  $self->output_flush();
+  $self->headers->clear();
+
+  return <<"EOT"
+   <p>This document has moved <a href="$url">here</a>.</p>
+   <script>document.location.href="$url";</script>
+EOT
 }
 
 #########
